@@ -294,6 +294,7 @@ tb_on_button_press_event_cb (GtkWidget *tb, GdkEventButton *event,
 
 	    gtk_icon_view_unselect_all (GTK_ICON_VIEW (tb));
 	    gtk_icon_view_select_path (GTK_ICON_VIEW (tb), path);
+	    gtk_icon_view_set_cursor (GTK_ICON_VIEW (tb), path, NULL, FALSE);
 
 	    eog_thumb_view_popup_menu (EOG_THUMB_VIEW (tb), event);
 	    
@@ -348,7 +349,6 @@ tb_on_drag_data_get_cb (GtkWidget        *widget,
 	
 }
 
-#ifdef HAVE_GTK_TOOLTIP
 static gboolean 
 tb_on_query_tooltip_cb (GtkWidget  *widget,
 			gint        x,
@@ -365,6 +365,7 @@ tb_on_query_tooltip_cb (GtkWidget  *widget,
 	gchar *uri_str, *mime_str;
 	const gchar *type_str;
 	GError *error = NULL;
+	GnomeVFSURI *uri;
 #ifdef HAVE_EXIF
 	ExifData *exif_data;
 #endif	
@@ -408,9 +409,22 @@ tb_on_query_tooltip_cb (GtkWidget  *widget,
 
 	eog_image_get_size (image, &width, &height);
 	
-	uri_str = eog_image_get_uri_for_display (image);
+	uri = eog_image_get_uri (image);
+	uri_str = gnome_vfs_uri_to_string (uri, GNOME_VFS_URI_HIDE_NONE);
+	gnome_vfs_uri_unref (uri);
 
 	mime_str = gnome_vfs_get_mime_type (uri_str);
+	
+	if (G_UNLIKELY (mime_str == NULL)) {
+		g_free (uri_str);
+		g_free (bytes);
+#ifdef HAVE_EXIF
+		exif_data_unref (exif_data);
+#endif
+		g_object_unref (image);
+		return FALSE;
+	}
+
 	type_str = gnome_vfs_mime_get_description (mime_str);
 
 	tooltip_string = g_strdup_printf ("<b><big>%s</big></b>\n"
@@ -440,6 +454,7 @@ tb_on_query_tooltip_cb (GtkWidget  *widget,
 		g_free (tooltip_string);
 
 		tooltip_string = tmp;
+		exif_data_unref (exif_data);
 	}
 #endif
 
@@ -453,7 +468,6 @@ tb_on_query_tooltip_cb (GtkWidget  *widget,
 	
 	return TRUE;
 }
-#endif /* HAVE_GTK_TOOLTIP */
 
 static void
 eog_thumb_view_init (EogThumbView *tb)
@@ -488,15 +502,13 @@ eog_thumb_view_init (EogThumbView *tb)
 	gtk_icon_view_set_row_spacing (GTK_ICON_VIEW (tb),
 				       EOG_THUMB_VIEW_SPACING);
 
-#ifdef HAVE_GTK_TOOLTIP
 	g_object_set (tb, "has-tooltip", TRUE, NULL);
 
 	g_signal_connect (tb, 
 			  "query-tooltip",
 			  G_CALLBACK (tb_on_query_tooltip_cb), 
 			  NULL);
-#endif /* HAVE_GTK_TOOLTIP */	
-	
+
 	tb->priv->start_thumb = 0;
 	tb->priv->end_thumb = 0;
 	tb->priv->menu = NULL;
@@ -535,6 +547,7 @@ eog_thumb_view_set_model (EogThumbView *tb, EogListStore *store)
 	if (index >= 0) {
 		GtkTreePath *path = gtk_tree_path_new_from_indices (index, -1);
 		gtk_icon_view_select_path (GTK_ICON_VIEW (tb), path);
+		gtk_icon_view_set_cursor (GTK_ICON_VIEW (tb), path, NULL, FALSE);
 		gtk_icon_view_scroll_to_path (GTK_ICON_VIEW (tb), path, FALSE, 0, 0);
 		gtk_tree_path_free (path);
 	}
@@ -656,6 +669,7 @@ eog_thumb_view_set_current_image (EogThumbView *tb, EogImage *image,
 	}
 	
 	gtk_icon_view_select_path (GTK_ICON_VIEW (tb), path);
+	gtk_icon_view_set_cursor (GTK_ICON_VIEW (tb), path, NULL, FALSE);
 	gtk_icon_view_scroll_to_path (GTK_ICON_VIEW (tb), path, FALSE, 0, 0);
 
 	gtk_tree_path_free (path);
@@ -698,6 +712,8 @@ eog_thumb_view_select_single (EogThumbView *tb,
 		gtk_icon_view_unselect_all (GTK_ICON_VIEW (tb));
 		
 		switch (change) {
+		case EOG_THUMB_VIEW_SELECT_CURRENT:
+			break;
 		case EOG_THUMB_VIEW_SELECT_LEFT:
 			if (!gtk_tree_path_prev (path)) {
 				gtk_tree_path_free (path);
@@ -723,6 +739,7 @@ eog_thumb_view_select_single (EogThumbView *tb,
 	}
 
 	gtk_icon_view_select_path (GTK_ICON_VIEW (tb), path);
+	gtk_icon_view_set_cursor (GTK_ICON_VIEW (tb), path, NULL, FALSE);
 	gtk_icon_view_scroll_to_path (GTK_ICON_VIEW (tb), path, FALSE, 0, 0);
 	gtk_tree_path_free (path);
 }
